@@ -149,24 +149,27 @@ class FieldBase(metaclass=ABCMeta):
         Args:
             filename (str):
                 Path where the data is stored
+            metadata (dict):
+                A dictionary of additional information that is stored with the file.
+                Note that not all formats support metadata.
             \**kwargs:
                 Additional parameters may be supported for some formats 
         """
         extension = Path(filename).suffix.lower()
 
         if extension in {".hdf", ".hdf5", ".he5", ".h5"}:
+            # save data in hdf5 format
             import h5py
 
             with h5py.File(filename, "w") as fp:
                 self._write_hdf_dataset(fp, **kwargs)
 
         elif extension in {".png", ".jpg", ".jpeg", ".tif", ".pdf", ".svg"}:
+            # save data as an image
             self._write_to_image(filename, **kwargs)
 
         else:
-            raise ValueError(
-                f"Do not know how to save data to file with extensions `{extension}`"
-            )
+            raise ValueError(f"Do not know how to save data to `*{extension}`")
 
     def _write_hdf_dataset(self, hdf_path, key: str = "data"):
         """ write data to a given hdf5 path `hdf_path` """
@@ -201,9 +204,8 @@ class FieldBase(metaclass=ABCMeta):
         from .scalar import ScalarField  # @Reimport
 
         # check whether they are the same class
-        class_compatible = self.__class__ == other.__class__ or (
-            accept_scalar and isinstance(other, ScalarField)
-        )
+        is_scalar = accept_scalar and isinstance(other, ScalarField)
+        class_compatible = self.__class__ == other.__class__ or is_scalar
         if not class_compatible:
             raise TypeError("Fields are incompatible")
 
@@ -516,14 +518,12 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
                 data = np.zeros(shape, dtype=np.double)
             elif isinstance(data, DataFieldBase):
                 # we need to make a copy to make sure the data is writeable
-                data = np.array(
-                    np.broadcast_to(data.data, shape), dtype=np.double, copy=True
-                )
+                data_reshaped = np.broadcast_to(data.data, shape)
+                data = np.array(data_reshaped, dtype=np.double, copy=True)
             else:
                 # we need to make a copy to make sure the data is writeable
-                data = np.array(
-                    np.broadcast_to(data, shape), dtype=np.double, copy=True
-                )
+                data_reshaped = np.broadcast_to(data, shape)
+                data = np.array(data_reshaped, dtype=np.double, copy=True)
 
         elif data is not None:
             # class does not manage its own data
@@ -1633,7 +1633,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
             kwargs = reference.parameters.get("kwargs", {})
             data = self.get_vector_data(transpose=transpose)
             # remove old streamplot
-            reference.element.remove()
+            ax.cla()
             # update with new streamplot
             reference.element = ax.streamplot(
                 data["x"], data["y"], data["data_x"], data["data_y"], **kwargs
