@@ -116,6 +116,16 @@ class BoundaryPair(BoundaryAxisBase):
         self.low.value = value
         self.high.value = value
 
+    def scale_value(self, factor: float = 1):
+        """ scales the value of the boundary condition with the given factor
+        
+        Args:
+            value (float):
+                Scales the value associated with the boundary condition by the factor
+        """
+        self.low.value = factor * self.low.value  # type: ignore
+        self.high.value = factor * self.high.value  # type: ignore
+
     @classmethod
     def get_help(cls) -> str:
         """ Return information on how boundary conditions can be set """
@@ -194,8 +204,8 @@ class BoundaryPair(BoundaryAxisBase):
                 else:
                     # if the length is strange, the format must be wrong
                     raise ValueError(
-                        "List of boundary condition should be of of length 2, not : "
-                        f"`{data}`. " + cls.get_help()
+                        "Expected two conditions for the two sides of the axis, but "
+                        f"got `{data}`. " + cls.get_help()
                     )
 
         return cls(low, high)
@@ -566,18 +576,24 @@ def get_boundary_axis(
     Returns:
         BoundaryAxisBase: The boundary condition for the axis
     """
+    # handle special constructs that describe boundary conditions
+    if data == "natural" or data == "auto_periodic_neumann":
+        # automatic choice between periodic and Neumann condition
+        data = "periodic" if grid.periodic[axis] else "derivative"
+    elif data == "auto_periodic_dirichlet":
+        # automatic choice between periodic and Dirichlet condition
+        data = "periodic" if grid.periodic[axis] else "value"
+
+    # handle different types of data that specify boundary conditions
     if isinstance(data, BoundaryAxisBase):
         # boundary is already in the correct format
         return data
-
     elif data == "periodic" or data == ("periodic", "periodic"):
         # initialize a periodic boundary condition
         return BoundaryPeriodic(grid, axis)
-
     elif isinstance(data, dict) and data.get("type") == "periodic":
         # initialize a periodic boundary condition
         return BoundaryPeriodic(grid, axis)
-
     else:
         # initialize independent boundary conditions for the two sides
         return BoundaryPair.from_data(grid, axis, data, rank=rank)
