@@ -560,7 +560,7 @@ class BCBase(metaclass=ABCMeta):
             boundary_class = cls._conditions[condition]
         except KeyError:
             raise ValueError(
-                f"Boundary condition `{condition}` not defined." + cls.get_help()
+                f"Boundary condition `{condition}` not defined. " + cls.get_help()
             )
 
         # create the actual class
@@ -643,10 +643,6 @@ class BCBase(metaclass=ABCMeta):
             assert data.grid == grid and data.axis == axis and data.rank == rank
             return data.copy(upper=upper)
 
-        elif data == "natural":
-            # special case of a vanishing derivative
-            return DirichletBC(grid, axis, upper=upper, rank=rank)
-
         elif isinstance(data, dict):
             # create from dictionary
             return cls.from_dict(grid, axis, upper=upper, data=data, rank=rank)
