@@ -12,7 +12,7 @@ from ..fields import ScalarField
 from ..grids.boundaries.axes import BoundariesData
 from ..tools.docstrings import fill_in_docstring
 from ..tools.numba import jit, nb
-from .base import PDEBase
+from .base import PDEBase, expr_prod
 
 
 class AllenCahnPDE(PDEBase):
@@ -44,6 +44,11 @@ class AllenCahnPDE(PDEBase):
         self.interface_width = interface_width
         self.bc = bc
 
+    @property
+    def expression(self) -> str:
+        """ str: the expression of the right hand side of this PDE """
+        return f"{expr_prod(self.interface_width, 'laplace(c)')} - c**3 + c"
+
     def evolution_rate(  # type: ignore
         self, state: ScalarField, t: float = 0,
     ) -> ScalarField:
