@@ -12,7 +12,7 @@ from ..fields import ScalarField
 from ..grids.boundaries.axes import BoundariesData
 from ..tools.docstrings import fill_in_docstring
 from ..tools.numba import jit, nb
-from .base import PDEBase
+from .base import PDEBase, expr_prod
 
 
 class DiffusionPDE(PDEBase):
@@ -48,6 +48,11 @@ class DiffusionPDE(PDEBase):
         self.diffusivity = diffusivity
         self.bc = bc
 
+    @property
+    def expression(self) -> str:
+        """ str: the expression of the right hand side of this PDE """
+        return expr_prod(self.diffusivity, "laplace(c)")
+
     def evolution_rate(  # type: ignore
         self, state: ScalarField, t: float = 0,
     ) -> ScalarField:
