@@ -5,24 +5,21 @@ Package that contains base classes for solvers
 """
 
 import logging
-from typing import Dict, Any, List  # @UnusedImport
 from abc import ABCMeta, abstractmethod
+from typing import Any, Dict, List  # @UnusedImport
 
 import numba as nb
 
-from ..pdes.base import PDEBase
 from ..fields.base import FieldBase
+from ..pdes.base import PDEBase
 from ..tools.misc import classproperty
 
 
-
 class SolverBase(metaclass=ABCMeta):
     """ base class for simulations """
 
-    
-    _subclasses: Dict[str, 'SolverBase'] = {}  # all inheriting classes
-    
-        
+    _subclasses: Dict[str, "SolverBase"] = {}  # all inheriting classes
+
     def __init__(self, pde: PDEBase):
         """ initialize the solver
         
@@ -31,22 +28,21 @@ class SolverBase(metaclass=ABCMeta):
                 The partial differential equation that should be solved
         """
         self.pde = pde
-        self.info: Dict[str, Any] = {'class': self.__class__.__name__,
-                                     'pde_class': self.pde.__class__.__name__}
+        self.info: Dict[str, Any] = {
+            "class": self.__class__.__name__,
+            "pde_class": self.pde.__class__.__name__,
+        }
         self._logger = logging.getLogger(self.__class__.__name__)
-        
 
     def __init_subclass__(cls, **kwargs):  # @NoSelf
         """ register all subclassess to reconstruct them later """
         super().__init_subclass__(**kwargs)
         cls._subclasses[cls.__name__] = cls
-        if hasattr(cls, 'name') and cls.name:
+        if hasattr(cls, "name") and cls.name:
             if cls.name in cls._subclasses:
-                logging.warn(f'Solver with name {cls.name} is already '
-                             'registered')
+                logging.warn(f"Solver with name {cls.name} is already registered")
             cls._subclasses[cls.name] = cls
 
-
     @classmethod
     def from_name(cls, name: str, pde: PDEBase, **kwargs) -> "SolverBase":
         r""" create solver class based on its name
@@ -72,24 +68,26 @@ class SolverBase(metaclass=ABCMeta):
             solver_class = cls._subclasses[name]
         except KeyError:
             # solver was not registered
-            solvers = (f"'{solver}'"
-                       for solver in sorted(cls._subclasses.keys())
-                       if not solver.endswith('Solver'))
-            raise ValueError(f"Unknown solver method '{name}'. Registered "
-                             f"solvers are {', '.join(solvers)}")
+            solvers = (
+                f"'{solver}'"
+                for solver in sorted(cls._subclasses.keys())
+                if not solver.endswith("Solver")
+            )
+            raise ValueError(
+                f"Unknown solver method '{name}'. Registered solvers are "
+                + ", ".join(solvers)
+            )
 
         return solver_class(pde, **kwargs)  # type: ignore
-    
-    
+
     @classproperty
     def registered_solvers(cls) -> List[str]:  # @NoSelf
         """ list of str: the names of the registered solvers """
         return list(sorted(cls._subclasses.keys()))
-    
 
-    def _make_pde_rhs(self, state: FieldBase,
-                      backend: str = 'auto',
-                      allow_stochastic: bool = False):
+    def _make_pde_rhs(
+        self, state: FieldBase, backend: str = "auto", allow_stochastic: bool = False
+    ):
         """ obtain a function for evaluating the right hand side
         
         Args:
@@ -116,26 +114,24 @@ class SolverBase(metaclass=ABCMeta):
             the associated noise.
         """
         if self.pde.is_sde and not allow_stochastic:
-            raise RuntimeError(f'The chosen stepper does not support '
-                               'stochastic equations')
-        
+            raise RuntimeError(
+                f"The chosen stepper does not support stochastic equations"
+            )
+
         if self.pde.is_sde:
             rhs = self.pde.make_sde_rhs(state, backend=backend)
         else:
             rhs = self.pde.make_pde_rhs(state, backend=backend)
-            
-        if hasattr(rhs, '_backend'):
-            self.info['backend'] = rhs._backend  # type: ignore
+
+        if hasattr(rhs, "_backend"):
+            self.info["backend"] = rhs._backend  # type: ignore
         elif isinstance(rhs, nb.dispatcher.Dispatcher):
-            self.info['backend'] = 'numba'
-        else:           
-            self.info['backend'] = 'undetermined'
-        
+            self.info["backend"] = "numba"
+        else:
+            self.info["backend"] = "undetermined"
+
         return rhs
-            
 
     @abstractmethod
     def make_stepper(self, state, dt: float = None):
         pass
-   
-
