@@ -10,14 +10,11 @@ Miscallenous python functions
    preserve_scalars
    decorator_arguments
    skipUnlessModule
-   get_progress_bar_class
-   display_progress
    import_class
    classproperty
    hybridmethod
    estimate_computation_speed
    hdf_write_attributes
-   in_jupyter_notebook
 
 .. codeauthor:: David Zwicker <david.zwicker@ds.mpg.de>
 """
@@ -29,12 +26,15 @@ import json
 import os
 import sys
 import unittest
-import warnings
 from pathlib import Path
 from typing import Any, Callable, Dict, List, Union
 
 import numpy as np
 
+# import functions moved on 2020-07-27
+# using this path for import is deprecated
+from .output import display_progress, get_progress_bar_class  # @UnusedImport
+
 
 def module_available(module_name: str) -> bool:
     """ check whether a python module is available
@@ -182,92 +182,6 @@ def skipUnlessModule(module_name: str) -> Callable:
         return unittest.skip(f"requires {module_name}")
 
 
-class MockProgress:
-    """ indicates progress by printing dots to stderr """
-
-    def __init__(self, iterable=None, *args, **kwargs):
-        self.iterable = iterable
-        self.n = self.total = 0
-        self.disable = False
-
-    def __iter__(self):
-        return iter(self.iterable)
-
-    def close(self, *args, **kwargs):
-        pass
-
-    def refresh(self, *args, **kwargs):
-        sys.stderr.write(".")
-        sys.stderr.flush()
-
-    def set_description(self, msg: str, refresh: bool = True, *args, **kwargs):
-        if refresh:
-            self.refresh()
-
-
-def get_progress_bar_class():
-    """ returns a class that behaves as progress bar.
-    
-    This either uses classes from the optional `tqdm` package or a simple
-    version that writes dots to stderr, if the class it not available.
-    """
-    try:
-        # try importing the tqdm package
-        import tqdm
-
-    except ImportError:
-        # create a mock class, since tqdm is not available
-        # progress bar package does not seem to be available
-        warnings.warn(
-            "`tqdm` package is not available. Progress will be indicated by dots."
-        )
-        progress_bar_class = MockProgress
-
-    else:
-        # tqdm is available => decide which class to return
-        tqdm_version = tuple(int(v) for v in tqdm.__version__.split(".")[:2])
-        if tqdm_version >= (4, 40):
-            # optionally import notebook progress bar in recent version
-            try:
-                # check whether progress bar can use a widget
-                import ipywidgets  # @UnusedImport
-            except ImportError:
-                # widgets are not available => use standard tqdm
-                progress_bar_class = tqdm.tqdm
-            else:
-                # use the fancier version of the progress bar in jupyter
-                from tqdm.auto import tqdm as progress_bar_class
-        else:
-            # only import text progress bar in older version
-            progress_bar_class = tqdm.tqdm
-            warnings.warn(
-                "Your version of tqdm is outdated. To get a nicer "
-                "progress bar update to at least version 4.40."
-            )
-
-    return progress_bar_class
-
-
-def display_progress(iterator, total=None, enabled=True, **kwargs):
-    r"""
-    displays a progress bar when iterating
-    
-    Args:
-        iterator (iter): The iterator
-        total (int): Total number of steps
-        enabled (bool): Flag determining whether the progress is display
-        **kwargs: All extra arguments are forwarded to the progress bar class
-        
-    Returns:
-        A class that behaves as the original iterator, but shows the progress
-        alongside iteration.
-    """
-    if not enabled:
-        return iterator
-
-    return get_progress_bar_class()(iterator, total=total, **kwargs)
-
-
 def import_class(identifier: str):
     """ import a class or module given an identifier 
     
@@ -436,18 +350,3 @@ def hdf_write_attributes(
                 raise
         else:
             hdf_path.attrs[key] = value_serialized
-
-
-def in_jupyter_notebook() -> bool:
-    """ checks whether we are in a jupyter notebook """
-    try:
-        from IPython import get_ipython
-    except ImportError:
-        return False
-
-    try:
-        ipython_config = get_ipython().config
-    except AttributeError:
-        return False
-
-    return "IPKernelApp" in ipython_config
