@@ -1,4 +1,4 @@
-'''
+"""
 Functions making use of spectral decompositions
 
 
@@ -9,7 +9,7 @@ Functions making use of spectral decompositions
 
 
 .. codeauthor:: David Zwicker <david.zwicker@ds.mpg.de>
-'''
+"""
 
 
 from typing import Callable, Tuple
@@ -17,18 +17,16 @@ from typing import Callable, Tuple
 import numpy as np
 
 try:
-    from pyfftw.interfaces.numpy_fft import rfftn as np_rfftn
     from pyfftw.interfaces.numpy_fft import irfftn as np_irfftn
+    from pyfftw.interfaces.numpy_fft import rfftn as np_rfftn
 except ImportError:
-    from numpy.fft import rfftn as np_rfftn
     from numpy.fft import irfftn as np_irfftn
+    from numpy.fft import rfftn as np_rfftn
 
 
-
-def make_colored_noise(shape: Tuple[int, ...],
-                       dx=1.,
-                       exponent: float = 0,
-                       scale: float = 1) -> Callable:
+def make_colored_noise(
+    shape: Tuple[int, ...], dx=1.0, exponent: float = 0, scale: float = 1
+) -> Callable:
     r""" Return a function creating an array of random values that obey
     
     .. math::
@@ -53,7 +51,7 @@ def make_colored_noise(shape: Tuple[int, ...],
     Returns:
         callable: a function returning a random realization
     """
-    # extract some information about the grid    
+    # extract some information about the grid
     dim = len(shape)
     dx = np.broadcast_to(dx, (dim,))
 
@@ -62,6 +60,7 @@ def make_colored_noise(shape: Tuple[int, ...],
         def noise_normal():
             """ return array of colored noise """
             return scale * np.random.randn(*shape)
+
         return noise_normal
 
     # deal with colored noise in the following
@@ -73,29 +72,28 @@ def make_colored_noise(shape: Tuple[int, ...],
             k = np.fft.rfftfreq(shape[i], dx[i])
         else:
             k = np.fft.fftfreq(shape[i], dx[i])
-        k2s = np.add.outer(k2s, k**2)
+        k2s = np.add.outer(k2s, k ** 2)
 
     # scaling of all modes with k != 0
     k2s.flat[0] = 1  # type: ignore
     scaling = 2 * np.pi * scale * k2s ** (exponent / 4)
     scaling.flat[0] = 0
-    
+
     # TODO: accelerate the FFT using the pyfftw package
 
     def noise_colored():
         """ return array of colored noise """
         # random field
         arr = np.random.randn(*shape)
-        
+
         # forward transform
         arr = np_rfftn(arr)
-        
+
         # scale according to frequency
         arr *= scaling
 
         # backwards transform
         arr = np_irfftn(arr, shape)
         return arr
-        
-    return noise_colored
 
+    return noise_colored
