@@ -23,7 +23,7 @@ from ..fields import FieldCollection
 from ..fields.base import DataFieldBase, FieldBase
 from ..storage.base import StorageBase
 from ..tools.docstrings import fill_in_docstring
-from ..tools.misc import display_progress
+from ..tools.output import display_progress
 from ..tools.plotting import PlotReference, plot_on_axes, plot_on_figure
 
 _logger = logging.getLogger(__name__)
@@ -491,7 +491,10 @@ class ScalarFieldPlot:
 def plot_magnitudes(
     storage: StorageBase, quantities=None, ax=None, **kwargs
 ) -> PlotReference:
-    r""" plot spatially integrated quantities as a function of time
+    r""" plot spatially averaged quantities as a function of time
+    
+    For scalar fields, the default is to plot the average value while the averaged norm
+    is plotted for vector fields.
     
     Args:
         storage:
@@ -608,9 +611,12 @@ def _plot_kymograph(
     ax.set_aspect("auto")
 
     if colorbar:
-        from ..tools.plotting import add_scaled_colorbar
+        import matplotlib.pyplot as plt
 
-        add_scaled_colorbar(axes_image, ax=ax)
+        plt.colorbar(axes_image, ax=ax)
+        # Note that we here do not use the method `add_scaled_colorbar` from the
+        # `pde.tools.plotting` module since this does not play well with axes with an
+        # explicit aspect ratio.
 
     return PlotReference(ax, axes_image)
 
